pub struct Explanation { /* private fields */ }Expand description
Collected explanation for the latest conflict or propagation round.
Implementations
Sourceimpl Explanation
impl Explanation
Sourcepub fn branch_literals(&self) -> impl Iterator<Item = NogoodLiteral> + '_
pub fn branch_literals(&self) -> impl Iterator<Item = NogoodLiteral> + '_
Returns branch literals in chronological order.
Sourcepub fn propagator_conflict_literals(&self) -> Option<Vec<NogoodLiteral>>
pub fn propagator_conflict_literals(&self) -> Option<Vec<NogoodLiteral>>
Returns literals from the most recent propagator-recorded conflict, if any.
Sourcepub fn unique_branch_literals(&self) -> Vec<NogoodLiteral>
pub fn unique_branch_literals(&self) -> Vec<NogoodLiteral>
Returns unique branch literals, keeping the latest assignment per variable.
Sourceimpl Explanation
impl Explanation
Sourcepub fn entries(&self) -> &[ChangeReason]
pub fn entries(&self) -> &[ChangeReason]
Returns recorded change reasons.
Sourcepub fn record(&mut self, reason: ChangeReason)
pub fn record(&mut self, reason: ChangeReason)
Records a change reason.