DomainView

Trait DomainView 

pub trait DomainView {
    type Value: Copy + Eq + Ord + Debug;

    // Required methods
    fn is_empty(&self) -> bool;
    fn is_fixed(&self) -> bool;
    fn size(&self) -> usize;
    fn min(&self) -> Option<Self::Value>;
    fn max(&self) -> Option<Self::Value>;
    fn contains(&self, value: Self::Value) -> bool;
}
Read-only interface for inspecting a variable domain.

Required Associated Types

type Value: Copy + Eq + Ord + Debug

Value type stored in the domain.

Required Methods

fn is_empty(&self) -> bool

Returns true when the domain contains no values.

fn is_fixed(&self) -> bool

Returns true when the domain contains exactly one value.

fn size(&self) -> usize

Returns the number of values in the domain.

fn min(&self) -> Option<Self::Value>

Returns the smallest value in the domain, if any.

fn max(&self) -> Option<Self::Value>

Returns the largest value in the domain, if any.

fn contains(&self, value: Self::Value) -> bool

Returns true when the domain contains value.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors